# Welcome to ro.py
ro.py is a Python wrapper for the Roblox web API.
## Documentation
You can view documentation for ro.py at [ro.py.jmksite.dev](https://ro.py.jmksite.dev/)

## Installation
You can install ro.py from pip:  
```
pip3 install ro-py
```

## Examples
(Update: I'm writing new examples. For now, look in the examples folder.)

## Credits
[@iranathan](https://github.com/iranathan) - maintainer
[@jmkdev](https://github.com/iranathan) - maintainer
[@nsg-mfd](https://github.com/nsg-mfd) - helped with endpoints

## Other Libraries
https://github.com/RbxAPI/Pyblox  
https://github.com/iranathan/robloxapi  
